********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Purpose: 	Produce Appendix Figure 1 
********************************************************************************

* Results stored in  Appendix\Results\AppendixFigure1.pdf
* First, run Alpha.do, CPY.do, FPY.do, YLL.do (inside DoFiles)

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Appendix/Logs/AppendixFigure1.log", replace

********************************************************************************

wbopendata, language(en - English) indicator(SP.POP.TOTL) long clear 			// region and WB country names 
rename countrycode country_code
rename countryname country_name
keep country_code country_name region incomelevel
bys country_code: gen aux = _n
keep if aux == 1
drop aux

drop if region=="NA"
drop if incomelevel=="NA"
drop if region==""
drop if incomelevel==""

*Latin America and Caribbean
replace region = "LAC" if region == "LCN"
* Europe and Central Asia
replace region = "ECA" if region == "ECS"
* East Asia and Pacific
replace region = "EAP" if region == "EAS"
* North America
replace region = "NAM" if region == "NAC"
* Sub-Saharan Africa
replace region = "SSA" if region == "SSF"
* Middle East and North Africa
replace region = "MENA" if region == "MEA"
* South Asia  
replace region = "SAS" if region == "SAS"
tempfile dataset
save 	`dataset'

wbopendata, language(en - English) indicator(NY.GNP.PCAP.KD) long clear 		// GNI PC (constant 2015 US$)
rename ny_gnp_pcap_kd gnipc2015
rename countrycode country_code
keep year country_code gnipc2015

bys country_code: gen aux = _n if gnipc2015~=.
gen aux2=-aux
sort country_code aux2
bys country_code: gen aux3=_n
keep if aux3==1
drop aux* year
sort country_code 
merge 1:m country_code using `dataset'
drop if _merge == 1
drop _merge
save `dataset', replace

// LTGM results
import excel "InputData/OUTPUT_default_nolinks_31March2023.xlsx", sheet("STATA_appF1") firstrow clear
rename sch_loss closures
rename quality qscore
order country_code qscore closures
merge 1:1 country_code using `dataset'
keep if _merge==3
drop _merge
save `dataset', replace

* Drop if pop<2.5MM
use `dataset', replace
drop if country_code=="BHR"
drop if country_code=="BWA"
drop if country_code=="GAB"
drop if country_code=="NAM"
drop if country_code=="SVN"
drop if country_code=="TLS"
drop if country_code=="TTO"

gen lays_loss = closures*qscore
reg lays_loss closures
predict lays_loss_hat
  
gen country_code2=country_code if lays_loss > 1.2*0.64*closures & closures>0.7
replace country_code2=country_code if lays_loss < 0.9*0.64*closures & closures>0.7
replace country_code2=country_code if lays_loss < 0.95*0.64*closures & closures>1

tw ///
scatter lays_loss closures if region== "SAS", aspectratio(0.65) mlabel(country_code2)  mlabcolor(navy%70) msymbol(circle) mcolor(navy%0) mlcolor(navy%70) lcolor(navy%70) msize(5pt) mlabsize(5pt) || ///
scatter lays_loss closures if region== "LAC",  mlabel(country_code2) mlabcolor(maroon%70) msymbol(diamond) mcolor(maroon%0) mlcolor(maroon%70) lcolor(maroon%0) msize(5pt) mlabsize(5pt) || ///
scatter lays_loss closures if region== "EAP",  mlabel(country_code2) mlabcolor(forest_green%70) msymbol(triangle) mcolor(forest_green%0) mlcolor(forest_green%70) lcolor(forest_green%70) msize(5pt) mlabsize(5pt) || ///
scatter lays_loss closures if region== "MENA", mlabel(country_code2) mlabcolor(dkorange%70) msymbol(square) mcolor(dkorange%0) mlcolor(dkorange%70) lcolor(dkorange%70) msize(5pt) mlabsize(5pt) || ///
scatter lays_loss closures if region== "ECA",  mlabel(country_code2) mlabcolor(emerald%70) msymbol(plus) mcolor(emerald%0) mlcolor(emerald%70) lcolor(emerald%70) msize(5pt) mlabsize(5pt) || ///
scatter lays_loss closures if region== "SSA",  mlabel(country_code2) mlabcolor(lavender%70) msymbol(X) mcolor(lavender%0) mlcolor(lavender%70) lcolor(lavender%70) msize(5pt) mlabsize(5pt) || ///
scatter lays_loss closures if region== "NAM",  mlabel(country_code2) mlabcolor(khaki%70) msymbol(V) mcolor(khaki%0) mlcolor(khaki%70) lcolor(khaki%70) msize(5pt) mlabsize(5pt) || ///
function y=x, range(0 1.5) lwidth(thin) lpatter(dash) lcolor(black) || ///
line lays_loss_hat closures, ///
lcolor(red) msize(7pt) mlabsize(7pt)   ///
xtitle("Years of school closures (UNESCO)", color(grey%70)) ///
ytitle("LAYS losses" "(School closures x Quality score)", color(grey%80)) ///
text(1.05 0.6 "45-degree line {&rarr}", place(r) size(small) color(black)) ///
text(0.72 1.05 "{&rarr}{&rarr}{&rarr}{&rarr}{&rarr}{&rarr}{&rarr} OLS fit (slope=0.64)", place(r) size(small) color(red)) ///
legend(order(1 2 3 4 5 6 7) row(1) label(1 SAS) label(2 LAC) label(3 EAP) label(4 MENA) label(5 ECA) label(6 SSA) label(7 NAM) size(10pt) color(grey%70)nobox region(style(none)) height(1)) ///
bgcolor(white) graphregion(color(white)) ///
ylabel(0(0.5)1.5 , labcolor(grey%80) grid format(%5.1f)) /// 
yscale(range(0 1.5) titlegap(2)) ///
xlabel(0(0.5)2 , labcolor(grey%80) grid format(%5.1f)) /// 
xscale(range(0 2) titlegap(2)) 
graph export "Appendix/Results/AppendixFigure1.pdf", as(pdf) replace

********************************************************************************

log close
