********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Purpose: 	Produce Appendix Figure 2 
********************************************************************************

* Results stored in  Appendix\Results\AppendixFigure2.pdf
* First, run Alpha.do, CPY.do, FPY.do, YLL.do (inside DoFiles)

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Appendix/Logs/AppendixFigure2.log", replace

********************************************************************************

use "OutputData/FPY.dta", clear											// countries to keep
keep code
tempfile countries
save 	`countries'

use "InputData/CLASS_historical.dta", clear
keep if year_data == 2020
drop year_release year_fiscal year_data region_povcalnet incgroup_current region_SSA ida_historical ida_current fcv_historical fcv_current 
rename economy country
rename incgroup_historical incomegroup
drop country

gen regioncode = ""
replace regioncode = "LAC" if region == "Latin America & Caribbean"
replace regioncode = "ECA" if region == "Europe & Central Asia"
replace regioncode = "EAP" if region == "East Asia & Pacific"
replace regioncode = "NAM" if region == "North America"
replace regioncode = "SSA" if region == "Sub-Saharan Africa"
replace regioncode = "MENA" if region == "Middle East & North Africa"
replace regioncode = "SAS" if region == "South Asia"

gen incomegroupcode = ""
replace incomegroupcode = "LI" if incomegroup == "Low income"
replace incomegroupcode = "LMI" if incomegroup == "Lower middle income"
replace incomegroupcode = "UMI" if incomegroup == "Upper middle income"
replace incomegroupcode = "HI" if incomegroup == "High income"

merge 1:1 code using `countries'												// countries to keep
drop if _m != 3
drop _m

merge 1:1 code using "OutputData/Alpha.dta"									// alpha data
drop if _m != 3
drop _m
keep  code region incomegroup regioncode incomegroupcode country mean2019 alpha_mean_e150

* Mean
sum mean2019 if incomegroupcode == "LI"
local mean2019_min_LI = `r(min)'
local mean2019_max_LI = `r(max)'
sum mean2019 if incomegroupcode == "LMI"
local mean2019_min_LMI = `r(min)'
local mean2019_max_LMI = `r(max)'
sum mean2019 if incomegroupcode == "UMI"
local mean2019_min_UMI = `r(min)'
local mean2019_max_UMI = `r(max)'
sum mean2019 if incomegroupcode == "HI"
local mean2019_min_HI = `r(min)'
local mean2019_max_HI = `r(max)'

sum alpha_mean_e150 if incomegroupcode == "LI"
gen alpha_mean_LI = `r(mean)' 
sum alpha_mean_e150 if incomegroupcode == "LMI"
gen alpha_mean_LMI = `r(mean)' if incomegroupcode == "LMI"
sum alpha_mean_e150 if incomegroupcode == "UMI"
gen alpha_mean_UMI = `r(mean)' if incomegroupcode == "UMI"
sum alpha_mean_e150 if incomegroupcode == "HI"
gen alpha_mean_HI = `r(mean)' if incomegroupcode == "HI"

sum alpha_mean_e150 
local alpha_mean_all = `r(mean)'
dis `alpha_mean_all'

tw ///
scatter alpha_mean_e150 mean2019 if incomegroupcode== "LI",  mlabcolor(navy%70) msymbol(circle) mcolor(navy%0) mlcolor(navy%70) lcolor(navy%70) msize(5pt) mlabsize(5pt) || ///
scatter alpha_mean_e150 mean2019 if incomegroupcode== "LMI",  mlabcolor(maroon%70) msymbol(diamond) mcolor(maroon%0) mlcolor(maroon%70) lcolor(maroon%0) msize(5pt) mlabsize(5pt) || ///
scatter alpha_mean_e150 mean2019 if incomegroupcode== "UMI", mlabcolor(forest_green%70) msymbol(triangle) mcolor(forest_green%0) mlcolor(forest_green%70) lcolor(forest_green%70) msize(5pt) mlabsize(5pt) || ///
scatter alpha_mean_e150 mean2019 if incomegroupcode== "HI", mlabcolor(dkorange%70) msymbol(square) mcolor(dkorange%0) mlcolor(dkorange%70) lcolor(dkorange%70) msize(5pt) mlabsize(5pt)  || ///
(line alpha_mean_LI mean2019 if mean2019 < 15, lwidth(0.5) lcolor(navy%70)) ///
(line alpha_mean_LMI mean2019, lwidth(0.5) lcolor(maroon%70)) ///
(line alpha_mean_UMI mean2019, lwidth(0.5) lcolor(forest_green%70)) ///
(line alpha_mean_HI mean2019, lwidth(0.5) lcolor(dkorange%70)),	///
yline(`alpha_mean_all', lpattern(dash) lcolor(black) lwidth(0.5)) 						///
xtitle("Mean income per capita (2017$ per person per day)", color(grey%70)) ///
ytitle("Calibrated α", color(grey%80)) ///
legend(order(1 2 3 4) row(1) label(1 LI) label(2 LMI) label(3 UMI) label(4 HI) size(10pt) color(grey%70)nobox region(style(none)) height(1)) ///
bgcolor(white) graphregion(color(white)) ///
ylabel(0(2)12 , labcolor(grey%80) grid ) /// 
yscale(range(0 12) titlegap(2)) ///
xlabel(0(10)90 , labcolor(grey%80) grid ) /// 
xscale(range(0 90) titlegap(2)) 			///
text(1.2 10 "LI: 1.47", size(7.5pt))			///
text(2.2 14 "LMI: 2.45", size(7.5pt))				///
text(3.4 28 "UMI: 3.70", size(7.5pt))				///
text(6.95 79 "HI: 7.24", size(7.5pt))				///
text(3.7 77.7 "World: 4.02", size(7.5pt))			
graph display, xsize(6)
graph export "Appendix/Results/AppendixFigure2.pdf", as(pdf) replace

********************************************************************************

log close
