********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Date: 		11/10/2023
*** Author: 	Nishant Yonzan
*** Purpose: 	Calculate total additional number of poor in 2020 and 2021 
********************************************************************************

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Logs/CPY.log", replace

********************************************************************************

*********************************
*** WELFARE DISTRIBUTION DATA ***
*********************************

use "InputData/GlobalDist_1000bins_MYLseptember23_limitedvars.dta", clear
keep country code quantile pop2020 pop2021 welf2020 welf2021 *2020_precovid *2021_precovid welf2019

bysort code: egen median2019 = median(welf2019)									// medians for societal poverty
gen 	socpovline2019 	= max(2.15, 1.15 + median2019/2)						// anchored socpovline in 2019
drop welf2019 median2019

ren welf*_precovid welfprecovid*
reshape long welf welfprecovid pop, i(country code quantile socpovline2019) j(year) 
ren welf welfcovid 

foreach v of varlist welf* { 													
	local s = substr("`v'",5,.)
	gen extpov`s'  = `v'<2.15													// extreme poverty 
	gen socpov`s' = `v'<socpovline2019											// societal poverty
}
drop socpovline2019

collapse extpov* socpov* (rawsum) pop [aw=pop], by(country code year) 			// headcount per country
reshape long extpov socpov, i(country code year pop) j(scenario) string
gen extpoor = extpov * pop 														// number of poor
gen socpoor = socpov * pop

bys code year (scenario): gen addextpov  = extpov - extpov[_n+1] 
bys code year (scenario): gen addsocpov  = socpov - socpov[_n+1] 
bys code year (scenario): gen addextpoor = extpoor - extpoor[_n+1] 
bys code year (scenario): gen addsocpoor = socpoor - socpoor[_n+1] 

drop if scenario=="precovid"
keep code year add*poor

reshape wide *poor, i(code) j(year)

order code addextpoor* addsocpoor*

label var addextpoor2020 	"CPY, Total additional extreme poor (millions) in 2020"
label var addextpoor2021 	"CPY, Total additional extreme poor (millions) in 2021"
label var addsocpoor2020 	"CPY, Total additional societal poor (millions) in 2020" 
label var addsocpoor2021 	"CPY, Total additional societal poor (millions) in 2021" 

export excel using "OutputData/CPY.xlsx", firstrow(varlabels) replace
save "OutputData/CPY.dta", replace

********************************************************************************

log close
