********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Purpose: 	Produce Figure 1 
********************************************************************************

* Results stored in  Results\Figure1.pdf
* First, run Alpha.do, CPY.do, FPY.do, YLL.do (inside DoFiles)

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Logs/Figure1.log", replace

********************************************************************************

use "OutputData/FPY.dta", clear													// FPY
rename region_wb region	
rename incgroup2019 incomegroup
rename code countrycode
rename disaddsocpoor FPY
drop gdppc2019_weo totaddpoor totaddsocpoor disaddpoor
tempfile FPY
save 	`FPY', replace

use "OutputData/CPY.dta", clear													// CPY
rename code countrycode
rename addsocpoor2020 CPY2020
rename addsocpoor2021 CPY2021
keep countrycode CPY2020 CPY2021
tempfile CPY
save 	`CPY', replace

use "OutputData/YLL.dta", clear													// YLL
rename year_life_lost YLL
tempfile YLL
save 	`YLL', replace

wbopendata, language(en - English) indicator(NY.GNP.PCAP.CD) long clear			// GNIPC 2020
label variable ny_gnp_pcap_cd "GNI per capita, Atlas method (current US$)"
keep if year==2020
rename ny_gnp_pcap_cd gnipc2020
label variable gnipc2020 "2020 GNI per capita, Atlas method (current US$)"
keep countrycode gnipc2020
rename countrycode countrycode
tempfile gnipc2020
save 	`gnipc2020', replace

use `FPY', clear																// merge (countries used are in FPY)
merge 1:1 countrycode using `CPY'
assert _m != 1
drop if _m == 2
drop _m
merge 1:1 countrycode using `YLL'
assert _m != 1
drop if _m == 2
drop _m
merge 1:1 countrycode using `gnipc2020'
assert _m != 1
drop if _m == 2
drop _m

gen regioncode = ""																
replace regioncode = "LAC" if region == "Latin America & Caribbean"
replace regioncode = "ECA" if region == "Europe & Central Asia"
replace regioncode = "EAP" if region == "East Asia & Pacific"
replace regioncode = "NAM" if region == "North America"
replace regioncode = "SSA" if region == "Sub-Saharan Africa"
replace regioncode = "MENA" if region == "Middle East & North Africa"
replace regioncode = "SAS" if region == "South Asia"

gen incomegroupcode = ""														
replace incomegroupcode = "LI" if incomegroup == "Low income"
replace incomegroupcode = "LMI" if incomegroup == "Lower middle income"
replace incomegroupcode = "UMI" if incomegroup == "Upper middle income"
replace incomegroupcode = "HI" if incomegroup == "High income"

																				
gen YLL_per_100 = YLL/(pop2019*10000)											// variables per 100 people
gen FPY_per_100 = FPY*1000000/(pop2019*1000000/100)
gen CPY_per_100 = (CPY2020+CPY2021)*1000000/(pop2019*1000000/100)

gen ln_gnipc2020 = ln(gnipc2020)
sort gnipc2020

lpoly YLL_per_100 ln_gnipc2020, at(ln_gnipc2020) gen(YLLfit) bwidth(0.75) nograph
lpoly CPY_per_100 ln_gnipc2020, at(ln_gnipc2020) gen(CPYfit) bwidth(0.75) nograph
lpoly FPY_per_100 ln_gnipc2020, at(ln_gnipc2020) gen(FPYfit) bwidth(0.75) nograph

twoway  ///
(line YLLfit gnipc2020, lcolor(black) lwidth(0.5) lcolor(navy%70)) ///
(line FPYfit gnipc2020, lcolor(black) lwidth(0.5) lcolor(forest_green%70) lpattern(dash)) ///
(line CPYfit gnipc2020, lcolor(black) lwidth(0.5) lcolor(maroon%70) lpattern(dash_dot_dot)), ///
xline(1046, lpattern(dot) lcolor(black) lwidth(0.4)) 						///
xline(4096, lpattern(dot) lcolor(black) lwidth(0.4)) 						///
xline(12695, lpattern(dot) lcolor(black) lwidth(0.4)) 					///
text(3 500 "Low Income", size(9pt))											///
text(3 2010 "Low-Middle", size(9pt)) 										///
text(2.25 2010 "Income", size(9pt)) 										///
text(3 7310 "Upper-Middle", size(9pt)) 										///
text(2.25 7310 "Income", size(9pt)) 										///
text(3 23010 "High Income", size(9pt)) 										///
graphregion(color(white)) bgcolor(white) 									///
ytitle(Years per 100 people) 												///
xtitle("GNI PC, Atlas Method (2020 US$, log{subscript:2} scale)") 			///
xsc(log) xlabel(250 500 1000 2000 4000 8000 16000 32000 64000) 				///
xscale(range(250 64000) titlegap(1)) 										///
ylabel(0(5)15 , labcolor(grey%80) ) 										/// 
yscale(range(0 15) titlegap(1)) 											///
legend(order(1 2 3) label(1 Years of Life Lost (YLL)) label(2 Future Poverty Years (FPY)) label(3 Current Poverty Years (CPY)) size(9pt)  col(1) position(2) ring(0)) 
graph export "Results/Figure1.pdf", as(pdf) replace

********************************************************************************

log close
