********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Date: 		11/14/2023
*** Author: 	Jed Friedman
*** Purpose: 	Use mortaility data to compute YLL due Covid in 2020 and 2021
********************************************************************************

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Logs/YLL.log", replace

********************************************************************************

// mortality data
import delimited using "InputData/IHME-GBD_2017_DATA-f89cefb0-1.csv", clear stringc(_all) delim(",")

ren age_id age_group_id
ren age_name age_group_name
ren location_name country
drop sex* cause* upper lower
keep if year == "2017"

foreach w in "All Ages" "Birth" "Early Neonatal" "Late Neonatal" "Neonatal" "Post Neonatal" "Under 5" "<20 years" "15-49 years" "25 plus" "5-14 years" "50-69 years" "70+ years" "80 plus" "10 to 19" "10 to 24" "<70 years" "Age-standardized" "10 to 54" {
            drop if age_group_name == "`w'"
}

drop age_group_id
gen     age_group_id = 1 if age_group_name == "<1 year"
replace age_group_id = 2 if age_group_name == "1 to 4"
replace age_group_id = 3 if age_group_name == "5 to 9"
replace age_group_id = 4 if age_group_name == "10 to 14"
replace age_group_id = 5 if age_group_name == "15 to 19"
replace age_group_id = 6 if age_group_name == "20 to 24"
replace age_group_id = 7 if age_group_name == "25 to 29"
replace age_group_id = 8 if age_group_name == "30 to 34"
replace age_group_id = 9 if age_group_name == "35 to 39"
replace age_group_id = 10 if age_group_name == "40 to 44"
replace age_group_id = 11 if age_group_name == "45 to 49"
replace age_group_id = 12 if age_group_name == "50 to 54"
replace age_group_id = 13 if age_group_name == "55 to 59"
replace age_group_id = 14 if age_group_name == "60 to 64"
replace age_group_id = 15 if age_group_name == "65 to 69"
replace age_group_id = 16 if age_group_name == "70 to 74"
replace age_group_id = 17 if age_group_name == "75 to 79"
replace age_group_id = 18 if age_group_name == "80 to 84"
replace age_group_id = 19 if age_group_name == "85 to 89"
replace age_group_id = 20 if age_group_name == "90 to 94"
replace age_group_id = 21 if age_group_name == "95 plus"
label var age_group_id "Age group ID"

// country name harmonization
quietly {
        replace country="Cabo Verde" if country=="Cape Verde"
        replace country="Congo, Republic of" if country=="Congo"
        replace country="Congo, Democratic Republic of" if country=="Democratic Republic of the Congo"
        replace country="Iran, Islamic Republic of" if country=="Iran"
        replace country="Kyrgyz Republic" if country=="Kyrgyzstan"
        replace country="Lao People's Democratic Republic" if country=="Laos"
        replace country="North Macedonia" if country=="Macedonia"
        replace country="Russian Federation" if country=="Russia"
        replace country="St. Lucia" if country=="Saint Lucia"
        replace country="St. Vincent and the Grenadines" if country=="Saint Vincent and the Grenadines"
        replace country="Slovak Republic" if country=="Slovakia" 
        replace country="Gambia, The" if country=="The Gambia"
        replace country="Venezuela, Republica Bolivariana de" if country=="Venezuela"
        replace country = "Egypt, Arab Republic of" if country == "Egypt"
        replace country = "Micronesia, Federated States of" if country == "Federated States of Micronesia"
        replace country = "Yemen, Republic of" if country == "Yemen"
        replace country = "Korea, Republic of" if country == "South Korea"
        replace country = "Syrian Arab Republic" if country == "Syria"
}

// dropping regions and subnational entities
quietly {
        foreach country in "Africa" "African Region" "African Union" "America" "American Samoa" "Andean Latin America" "Asia" "Australasia" "Caribbean" "Central Asia" "Central Europe" "Central Europe, Eastern Europe, and Central Asia" "Central Latin America" "Central Sub-Saharan Africa" "Commonwealth" "Commonwealth High Income" "Commonwealth Low Income" "Commonwealth Middle Income" ECA ECE ECLAC ESCAP ESCWA "EU and EFTA" "EU-15" "East Asia" "East Asia & Pacific - WB" "Eastern Europe" "Eastern Mediterranean Region" "Eastern Sub-Saharan Africa" "England" Europe "Europe & Central Asia - WB" "European Free Trade Association" "European Region" "European Union" "Four World Regions" G20 Global "Gulf Cooperation Council" "High SDI" "High-income" "High-income Asia Pacific" "High-income North America" "High-middle SDI" "Latin America & Caribbean - WB" "Latin America and Caribbean" "Low SDI"  "Low-middle SDI" "Middle East & North Africa - WB" "Middle SDI" "Nordic Region" "North Africa and Middle East" "North America"  "Northern Ireland" "OECD Countries" "Oceania" "Region of the Americas" "Scotland" "South Asia" "South Asia - WB" "South-East Asia Region" "Southeast Asia" "Southeast Asia, East Asia, and Oceania" "Southern African Development Community" "Southern Latin America" "Southern Sub-Saharan Africa" "Sub-Saharan Africa" "Sub-Saharan Africa - WB" "Tropical Latin America" "Virgin Islands, U.S." "WHO region" "Wales" "Western Europe" "Western Pacific Region"  "Western Sub-Saharan Africa" "World Bank High Income" "World Bank Income Levels" "World Bank Low Income" "World Bank Lower Middle Income" "World Bank Regions" "World Bank Upper Middle Income" "East Midlands" "East of England" "Greater London" "North East England" "North West England" "South East England" "South West England" "Stockholm" "West Midlands" "UN Regional Commissions"  "Yorkshire and the Humber" "Sweden except Stockholm"  "?saka" "Aguascalientes" "Aichi" "Akita" "Aomori" "Baja California" "Baja California Sur" "Campeche" "Chiapas" "Chiba" "Chihuahua" "Coahuila" "Colima" "Distrito Federal" "Durango" "Ehime" "Fuku" "Fukuoka" "Fukushima" "Gifu" "Guanajuato" "Guerrero" "Gunma" "Hidalgo" "Hiroshima" "Hokkaid?" "Hy?go" "Ibaraki" "Ishikaw" "Iwate" "Jalisco" "K?chi" "Kagawa" "Kagoshima" "Kanagawa"Kiribati Kumamoto Ky?to "MichoacÃ¡n de Ocampo" Mie Miyagi Miyazaki Morelos Nagano Nagasaki Nara Nayarit Niigata "Nuevo LeÃ³n" Oaxaca Okayama Okinawa Puebla QuerÃ©taro "Quintana Roo" Saga Saitama "San Luis PotosÃ­" San Luis PotosÃ­ Shimane Shizuoka Sinaloa Sonora T?ky? Tabasco Tamaulipas Tlaxcala Tochigi Tokushima Tottori Toyama  "Veracruz de Ignacio de la Llave" Wakayama Yamagata Yamaguchi Yamanashi "YucatÃ¡n" Zacatecas "Ãita" Fukui Ishikawa Shiga { 
                drop if country == "`country'"
        }
}
tempfile temp1
save `temp1', replace

// death are not reported '000
drop if metric_name == "Rate"
ren val number 
destring number, replace
replace number = number   
tempfile temp2
save `temp2', replace

// re-assessing rate to a rate per person
use `temp1', clear
drop if metric_name == "Number"
ren val rate
destring rate, replace
replace rate = rate/100000
label var rate "Mortality risk by age group"
	
merge 1:1 location_id country year age_group_id age_group_name using `temp2', nogen
foreach var in age_group_id year {
	destring `var', replace
}
																				
gen pop_alive_begin = int(number /rate)											// creating population by age and year
label var pop_alive_begin "Alive Population by age group at beginning of period"

// rectangularizing data
preserve
    keep country location_id
    duplicates drop
    tempfile temp3
	save `temp3', replace
restore

preserve
    keep age_group_name age_group_id
    duplicates drop
    tempfile temp4
	save `temp4', replace
restore

preserve
    keep country year age_group_id pop_alive_begin
    duplicates drop
    tempfile temp5
	save `temp5', replace
restore

keep   country year age_group_id number rate
fillin country year  age_group_id 

foreach var of varlist *number *rate {
    replace `var'  = 0 if _fillin
}
drop _fillin
merge m:1 country       using `temp3', nogen
merge m:1 age_group_id  using `temp4', nogen
merge m:1 country year age_group_id  using `temp5', nogen

bysort country year age_group_id: egen new_number = total(number)
bysort country year age_group_id: egen new_pop_alive_begin = total(pop_alive_begin)
sort country year age_group_id	
collapse new_pop_alive_begin new_number, by(country location_id year age_group_name age_group_id)
	
// creating new mortality rate by age, gender and year
gen mid_mortality = (new_number/new_pop_alive_begin)

ren new_number ndeath
ren mid_mortality mortality_rate
ren new_pop_alive_begin pop_alive_begin

order country year mortality age_group_id ndeath location_id pop_alive_begin

compress
keep if year == 2017

// mortality rate assumes a different definition
ren mortality_rate death_probability

gen years_of_life_lived = pop_alive_begin - ndeath/2

gen mortality_rate = ndeath/years_of_life_lived

gsort country - age_group_id
bysort country: gen total_persons_years = sum(years_of_life_lived)
gsort country + age_group_id

gen life_expectancy = total_persons_years/pop_alive_begin

// adjustment 
foreach var of varlist life_expectancy {
clonevar new_`var' = `var'
replace new_`var' = new_`var' * 4 if age_group_id == 2
replace new_`var' = new_`var' * 5 if age_group_id == 3
replace new_`var' = new_`var' * 5 if age_group_id == 4
replace new_`var' = new_`var' * 5 if age_group_id == 5
replace new_`var' = new_`var' * 5 if age_group_id == 6
replace new_`var' = new_`var' * 5 if age_group_id == 7
replace new_`var' = new_`var' * 5 if age_group_id == 8
replace new_`var' = new_`var' * 5 if age_group_id == 9
replace new_`var' = new_`var' * 5 if age_group_id == 10
replace new_`var' = new_`var' * 5 if age_group_id == 11
replace new_`var' = new_`var' * 5 if age_group_id == 12
replace new_`var' = new_`var' * 5 if age_group_id == 13
replace new_`var' = new_`var' * 5 if age_group_id == 14
replace new_`var' = new_`var' * 5 if age_group_id == 15
replace new_`var' = new_`var' * 5 if age_group_id == 16
replace new_`var' = new_`var' * 5 if age_group_id == 17
replace new_`var' = new_`var' * 5 if age_group_id == 18
replace new_`var' = new_`var' * 5 if age_group_id == 19
replace new_`var' = new_`var' * 5 if age_group_id == 20
replace new_`var' = 0 if age_group_id == 21
}

/****************************** Name correction ******************************/

// Get country codes:
//	1. Edit names so that it merges correctly with country codes database (CLASS_historical.dta)
//	   Countries that are not in the current database (names as in CLASS_historical.dta):
//		American Samoa
//		Aruba
//		British Virgin Islands
//		Cayman Islands
//		Channel Islands
//		Curaçao
//		Faeroe Islands
//		French Polynesia
//		Gibraltar
//		Hong Kong SAR, China
//		Isle of Man
//		Kiribati
//		Kosovo
//		Liechtenstein
//		Macao SAR, China
//		Monaco
//		Nauru
//		New Caledonia
//		Palau
//		San Marino
//		Sint Maarten (Dutch part)
//		St. Kitts and Nevis
//		St. Martin (French part)
//		Turks and Caicos Islands
//		Tuvalu
//		Virgin Islands (U.S.)
//	2. Keep only country names and country codes in CLASS_historical.dta, then merge with GBD_population_mortality.dta
//	3. Drop countries not in GBD_population_mortaility.dta (mentioned in step 1.)

//	1.
replace country = "Bahamas, The" if country == "The Bahamas"
replace country = "Brunei Darussalam" if country == "Brunei"
replace country = "Congo, Dem. Rep." if country == "Congo, Democratic Republic of"
replace country = "Congo, Rep." if country == "Congo, Republic of"
replace country = "Côte d'Ivoire" if country == "Cote d'Ivoire"
replace country = "Egypt, Arab Rep." if country == "Egypt, Arab Republic of"
replace country = "Eswatini" if country == "Swaziland"
replace country = "Iran, Islamic Rep." if country == "Iran, Islamic Republic of"
replace country = "Korea, Dem. Rep." if country == "North Korea"
replace country = "Korea, Rep." if country == "Korea, Republic of"
replace country = "Lao PDR" if country == "Lao People's Democratic Republic"
replace country = "Micronesia, Fed. Sts." if country == "Micronesia, Federated States of"
replace country = "São Tomé and Principe" if country == "Sao Tome and Principe"
replace country = "Taiwan, China" if country == "Taiwan (Province of China)"
replace country = "Venezuela, RB" if country == "Venezuela, Republica Bolivariana de"
replace country = "Yemen, Rep." if country == "Yemen, Republic of"
replace country = "West Bank and Gaza" if country == "Palestine"
tempfile GBD_population_mortality
save `GBD_population_mortality', replace

//	2.
use "InputData/CLASS_historical.dta", clear
keep if year_data == 2020
drop year_release year_fiscal year_data region region_povcalnet region_SSA incgroup_historical incgroup_current ida_historical ida_current fcv_historical fcv_current
rename economy country
merge 1:m country using `GBD_population_mortality'

//	3.
assert _m == 1 if country == "American Samoa" | country == "Aruba" 									///
| country == "British Virgin Islands" | country == "Cayman Islands" | country == "Channel Islands" 	///
| country == "Curaçao" | country == "Faeroe Islands" | country == "French Polynesia" 				///
| country == "Gibraltar" | country == "Hong Kong SAR, China" | country == "Isle of Man" 			///
| country == "Kiribati" | country == "Kosovo" 														///
| country == "Liechtenstein" | country == "Macao SAR, China" | country == "Monaco" 					///
| country == "Nauru" | country == "New Caledonia" | country == "Palau" | country == "San Marino" 	///
| country == "Sint Maarten (Dutch part)" | country == "St. Kitts and Nevis" 						///
| country == "St. Martin (French part)" | country == "Turks and Caicos Islands" 					///
| country == "Tuvalu" | country == "Virgin Islands (U.S.)" 
drop if country == "American Samoa" | country == "Aruba" 											///
| country == "British Virgin Islands" | country == "Cayman Islands" | country == "Channel Islands" 	///
| country == "Curaçao" | country == "Faeroe Islands" | country == "French Polynesia" 				///
| country == "Gibraltar" | country == "Hong Kong SAR, China" | country == "Isle of Man" 			///
| country == "Kiribati" | country == "Kosovo" 														///
| country == "Liechtenstein" | country == "Macao SAR, China" | country == "Monaco" 					///
| country == "Nauru" | country == "New Caledonia" | country == "Palau" | country == "San Marino" 	///
| country == "Sint Maarten (Dutch part)" | country == "St. Kitts and Nevis" 						///
| country == "St. Martin (French part)" | country == "Turks and Caicos Islands" 					///
| country == "Tuvalu" | country == "Virgin Islands (U.S.)" 
assert _m != 1 
assert _m != 2
drop _m 

rename country country_GBD_population_mortality
rename code countrycode

tempfile GBD_population_mortality
save `GBD_population_mortality', replace

/************************** End of name correction ***************************/

import excel using "InputData/Excess Deaths WHO.xlsx", firstrow clear
sort country age
bysort country age: egen total_expectedmean = sum(expectedmean)
bysort country age: egen total_acmmean = sum(acmmean)
bysort country age: egen total_excessmean = sum(excessmean)
keep country iso3 age total_expectedmean total_acmmean total_excessmean
duplicates drop country age, force

rename age age_group_name		
expand 6 if age_group_name == "0 to 24"
expand 3 if age_group_name == "25 to 39"
expand 2 if age_group_name == "40 to 49"
expand 2 if age_group_name == "50 to 59"
expand 2 if age_group_name == "60 to 69"
expand 2 if age_group_name == "70 to 79"
expand 4 if age_group_name == "80 plus"

gen s_no = .
bysort country age_group_name: replace s_no = _n

gen new_age_group = age_group_name

replace new_age_group = "<1" if age_group_name == "0 to 24" & s_no == 1
replace new_age_group = "1-4" if age_group_name == "0 to 24" & s_no == 2
replace new_age_group = "5-9" if age_group_name == "0 to 24" & s_no == 3
replace new_age_group = "10-14" if age_group_name == "0 to 24" & s_no == 4
replace new_age_group = "15-19" if age_group_name == "0 to 24" & s_no == 5
replace new_age_group = "20-24" if age_group_name == "0 to 24" & s_no == 6

replace new_age_group = "25-29" if age_group_name == "25 to 39" & s_no == 1
replace new_age_group = "30-34" if age_group_name == "25 to 39" & s_no == 2
replace new_age_group = "35-39" if age_group_name == "25 to 39" & s_no == 3

replace new_age_group = "40-44" if age_group_name == "40 to 49" & s_no == 1
replace new_age_group = "45-49" if age_group_name == "40 to 49" & s_no == 2

replace new_age_group = "50-54" if age_group_name == "50 to 59" & s_no == 1
replace new_age_group = "55-59" if age_group_name == "50 to 59" & s_no == 2

replace new_age_group = "60-64" if age_group_name == "60 to 69" & s_no == 1
replace new_age_group = "65-69" if age_group_name == "60 to 69" & s_no == 2

replace new_age_group = "70-74" if age_group_name == "70 to 79" & s_no == 1
replace new_age_group = "75-79" if age_group_name == "70 to 79" & s_no == 2

replace new_age_group = "80-84" if age_group_name == "80 plus" & s_no == 1
replace new_age_group = "85-89" if age_group_name == "80 plus" & s_no == 2
replace new_age_group = "90-94" if age_group_name == "80 plus" & s_no == 3
replace new_age_group = "95 plus" if age_group_name == "80 plus" & s_no == 4

gen     age_group_id = 1 if new_age_group == "<1"
replace age_group_id = 2 if new_age_group == "1-4"
replace age_group_id = 3 if new_age_group == "5-9"
replace age_group_id = 4 if new_age_group == "10-14"
replace age_group_id = 5 if new_age_group == "15-19"
replace age_group_id = 6 if new_age_group == "20-24"
replace age_group_id = 7 if new_age_group == "25-29"
replace age_group_id = 8 if new_age_group == "30-34"
replace age_group_id = 9 if new_age_group == "35-39"
replace age_group_id = 10 if new_age_group == "40-44"
replace age_group_id = 11 if new_age_group == "45-49"
replace age_group_id = 12 if new_age_group == "50-54"
replace age_group_id = 13 if new_age_group == "55-59"
replace age_group_id = 14 if new_age_group == "60-64"
replace age_group_id = 15 if new_age_group == "65-69"
replace age_group_id = 16 if new_age_group == "70-74"
replace age_group_id = 17 if new_age_group == "75-79"
replace age_group_id = 18 if new_age_group == "80-84"
replace age_group_id = 19 if new_age_group == "85-89"
replace age_group_id = 20 if new_age_group == "90-94"
replace age_group_id = 21 if new_age_group == "95 plus"
label var age_group_id "Age group ID"
		
drop age_group_name

// merge with corrected names 

rename iso3 countrycode
merge 1:1 countrycode age_group_id using `GBD_population_mortality'

* Not in GBD_population_mortality.dta:
* COK: Cook Islands
* KIR: Kiribati
* KNA: Saint Kitts and Nevis
* MCO: Monaco
* NIU: Niue
* NRU: Nauru
* PLW: Palau
* SMR: San Marino
* TUV: Tuvalu
assert _m == 1 if country == "Cook Islands" | country == "Kiribati" | country == "Saint Kitts and Nevis"	///
| country == "Monaco" | country == "Niue" | country == "Nauru" | country == "Palau" 						///
| country == "San Marino" | country == "Tuvalu"
drop if country == "Cook Islands" | country == "Kiribati" | country == "Saint Kitts and Nevis"	///
| country == "Monaco" | country == "Niue" | country == "Nauru" | country == "Palau" 			///
| country == "San Marino" | country == "Tuvalu"
assert _m != 1 

* Not in using (present in GBD_population_mortality.dta):
* BMU: Bermuda
* GRL: Greenland
* GUM: Guam
* MNP: Northern Mariana Islands
* PRI: Puerto Rico
* PSE: West Bank and Gaza
* TWN: Taiwan, China
assert _m == 2 if country_GBD_population_mortality == "Bermuda" | country_GBD_population_mortality == "Greenland"	///
| country_GBD_population_mortality == "Guam" | country_GBD_population_mortality == "Northern Mariana Islands"		///
| country_GBD_population_mortality == "Puerto Rico" | country_GBD_population_mortality == "West Bank and Gaza" 		///
| country_GBD_population_mortality == "Taiwan, China" 
drop if country_GBD_population_mortality == "Bermuda" | country_GBD_population_mortality == "Greenland"			///
| country_GBD_population_mortality == "Guam" | country_GBD_population_mortality == "Northern Mariana Islands"	///
| country_GBD_population_mortality == "Puerto Rico" | country_GBD_population_mortality == "West Bank and Gaza"	///
| country_GBD_population_mortality == "Taiwan, China" 
assert _m != 2
drop _m 
drop country_GBD_population_mortality
drop total_expectedmean	total_acmmean
gen excess_new = total_excessmean 

// equalize across all age_groups
replace excess_new = excess_new/6 if age_group_name == "0 to 24"
replace excess_new = excess_new/3 if age_group_name == "25 to 39"
replace excess_new = excess_new/2 if age_group_name == "40 to 49"
replace excess_new = excess_new/2 if age_group_name == "50 to 59"
replace excess_new = excess_new/2 if age_group_name == "60 to 69"
replace excess_new = excess_new/2 if age_group_name == "70 to 79"
replace excess_new = excess_new/3 if age_group_name == "80 plus"

gen year_life_lost = (excess_new * new_life_expectancy)
collapse (sum) pop_alive_begin year_life_lost, by(countrycode)
	
drop pop_alive_begin
label variable year_life_lost "YLL, Years of Life Lost"

export excel using "OutputData/YLL.xlsx", first(varlabels) replace
save "OutputData/YLL.dta", replace

********************************************************************************

log close
